@@ -17,9 +17,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "atktext.h"
+#include "atk.h"
 #include "atkmarshal.h"
-#include "atk-enum-types.h"
 
 #include <string.h>
 
@@ -221,7 +220,9 @@ atk_text_base_init (AtkTextIface *class)
        * @arg3: The new text inserted
        *
        * The "text-insert" signal is emitted when a new text is
-       * inserted.
+       * inserted. If the signal was not triggered by the user
+       * (e.g. typing or pasting text), the "system" detail should be
+       * included.
        */
       atk_text_signals[TEXT_INSERT] =
 	g_signal_new ("text_insert",
@@ -241,7 +242,9 @@ atk_text_base_init (AtkTextIface *class)
        * @arg3: The old text removed
        *
        * The "text-remove" signal is emitted when a new text is
-       * removed.
+       * removed. If the signal was not triggered by the user
+       * (e.g. typing or pasting text), the "system" detail should be
+       * included.
        */
       atk_text_signals[TEXT_REMOVE] =
 	g_signal_new ("text_remove",
@@ -577,7 +580,7 @@ atk_text_get_text_before_offset (AtkText          *text,
  * is from the start of the paragraph at or before the offset to the start
  * of the following paragraph after the offset.
  *
- * Since: 2.9.4
+ * Since: 2.10
  *
  * Returns: a newly allocated string containing the text at the @offset bounded
  *   by the specified @granularity. Use g_free() to free the returned string.
@@ -1066,10 +1069,8 @@ atk_text_get_range_extents (AtkText          *text,
 
   g_return_if_fail (ATK_IS_TEXT (text));
   g_return_if_fail (rect);
+  g_return_if_fail (start_offset >= 0 && start_offset < end_offset);
 
-  if (start_offset < 0 || start_offset >= end_offset)
-    return;
- 
   iface = ATK_TEXT_GET_IFACE (text);
 
   if (iface->get_range_extents)
@@ -1090,7 +1091,6 @@ atk_text_get_range_extents (AtkText          *text,
  *
  * Returns: (array zero-terminated=1): Array of AtkTextRange. The last
  *          element of the array returned by this function will be NULL.
- * Virtual: get_bounded_ranges
  **/
 AtkTextRange**
 atk_text_get_bounded_ranges (AtkText          *text,
